@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -69,40 +69,15 @@ import sys
 
 try:
     # Starting Python 3.8, importlib.metadata is available in the Python
-    # standard library.
+    # standard library and starting Python 3.10, the "select" interface is
+    # available on EntryPoints.
     import importlib.metadata as importlib_metadata
 except ImportError:
     import importlib_metadata
 
-from traits.api import HasTraits, List, ReadOnly, Str, TraitError
+from traits.api import HasTraits, List, ReadOnly, Str
 from traits.etsconfig.api import ETSConfig
 
-
-try:
-    provisional_toolkit = ETSConfig.provisional_toolkit
-except AttributeError:
-    from contextlib import contextmanager
-
-    # for backward compatibility
-    @contextmanager
-    def provisional_toolkit(toolkit_name):
-        """ Perform an operation with toolkit provisionally set
-
-        This sets the toolkit attribute of the ETSConfig object set to the
-        provided value. If the operation fails with an exception, the toolkit
-        is reset to nothing.
-        """
-        if ETSConfig.toolkit:
-            raise AttributeError("ETSConfig toolkit is already set")
-        ETSConfig.toolkit = toolkit_name
-        try:
-            yield
-        except:
-            # reset the toolkit state
-            ETSConfig._toolkit = ""
-            raise
-
-
 logger = logging.getLogger(__name__)
 
 
@@ -128,7 +103,7 @@ class Toolkit(HasTraits):
     packages = List(Str)
 
     def __init__(self, package, toolkit, *packages, **traits):
-        super(Toolkit, self).__init__(
+        super().__init__(
             package=package, toolkit=toolkit, packages=list(packages), **traits
         )
 
@@ -167,9 +142,9 @@ class Toolkit(HasTraits):
                     # the traceback's stack frame mentions the toolkit in question.
                     import traceback
 
-                    frames = traceback.extract_tb(sys.exc_traceback)
+                    frames = traceback.extract_tb(sys.exc_info()[2])
                     filename, lineno, function, text = frames[-1]
-                    if not package in filename:
+                    if package not in filename:
                         raise
             else:
                 obj = getattr(module, oname, None)
@@ -213,7 +188,15 @@ def import_toolkit(toolkit_name, entry_point="pyface.toolkits"):
         If no toolkit is found, or if the toolkit cannot be loaded for some
         reason.
     """
-    entry_point_group = importlib_metadata.entry_points()[entry_point]
+
+    # This compatibility layer can be removed when we drop support for
+    # Python < 3.10. Ref https://github.com/enthought/pyface/issues/999.
+    all_entry_points = importlib_metadata.entry_points()
+    if hasattr(all_entry_points, "select"):
+        entry_point_group = all_entry_points.select(group=entry_point)
+    else:
+        entry_point_group = all_entry_points[entry_point]
+
     plugins = [
         plugin for plugin in entry_point_group if plugin.name == toolkit_name
     ]
@@ -230,6 +213,7 @@ def import_toolkit(toolkit_name, entry_point="pyface.toolkits"):
         module_names = ", ".join(module_names)
         logger.warning(msg, entry_point, toolkit_name, module_names)
 
+    toolkit_exception = None
     for plugin in plugins:
         try:
             toolkit_object = plugin.load()
@@ -239,11 +223,12 @@ def import_toolkit(toolkit_name, entry_point="pyface.toolkits"):
             module_name = plugin.value.split(":")[0]
             logger.info(msg, plugin.name, module_name)
             logger.debug(exc, exc_info=True)
+            toolkit_exception = exc
 
     msg = "No {} plugin could be loaded for {}"
     msg = msg.format(entry_point, toolkit_name)
     logger.info(msg)
-    raise RuntimeError(msg)
+    raise RuntimeError(msg) from toolkit_exception
 
 
 def find_toolkit(entry_point, toolkits=None, priorities=default_priorities):
@@ -272,8 +257,6 @@ def find_toolkit(entry_point, toolkits=None, priorities=default_priorities):
 
     Raises
     ------
-    TraitError
-        If no working toolkit is found.
     RuntimeError
         If no ETSConfig.toolkit is set but the toolkit cannot be loaded for
         some reason.
@@ -281,10 +264,20 @@ def find_toolkit(entry_point, toolkits=None, priorities=default_priorities):
     if ETSConfig.toolkit:
         return import_toolkit(ETSConfig.toolkit, entry_point)
 
-    entry_points = [
-        plugin for plugin in importlib_metadata.entry_points()[entry_point]
-        if toolkits is None or plugin.name in toolkits
-    ]
+    # This compatibility layer can be removed when we drop support for
+    # Python < 3.10. Ref https://github.com/enthought/pyface/issues/999.
+    all_entry_points = importlib_metadata.entry_points()
+    if hasattr(all_entry_points, "select"):
+        entry_points = [
+            plugin for plugin in all_entry_points.select(group=entry_point)
+            if toolkits is None or plugin.name in toolkits
+        ]
+    else:
+        entry_points = [
+            plugin for plugin in all_entry_points[entry_point]
+            if toolkits is None or plugin.name in toolkits
+        ]
+
     for plugin in sorted(entry_points, key=priorities):
         try:
             with ETSConfig.provisional_toolkit(plugin.name):
@@ -299,5 +292,3 @@ def find_toolkit(entry_point, toolkits=None, priorities=default_priorities):
     # if all else fails, try to import the null toolkit.
     with ETSConfig.provisional_toolkit("null"):
         return import_toolkit("null", entry_point)
-
-    raise TraitError("Could not import any {} toolkit.".format(entry_point))
