@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -15,8 +15,8 @@ from traits.api import HasTraits, Instance, List
 
 
 from pyface.action.api import MenuBarManager, StatusBarManager, ToolBarManager
-from pyface.i_image_resource import IImageResource
 from pyface.i_window import IWindow
+from pyface.ui_traits import Image
 
 
 class IApplicationWindow(IWindow):
@@ -35,7 +35,7 @@ class IApplicationWindow(IWindow):
     # 'IApplicationWindow' interface ---------------------------------------
 
     #: The window icon.  The default is toolkit specific.
-    icon = Instance(IImageResource)
+    icon = Image()
 
     #: The menu bar manager (None iff there is no menu bar).
     menu_bar_manager = Instance(MenuBarManager)
@@ -128,10 +128,14 @@ class MApplicationWindow(HasTraits):
 
         if self.tool_bar_manager is not None:
             self.tool_bar_manager.destroy()
+
+        if self.status_bar_manager is not None:
+            self.status_bar_manager.destroy()
+
         for tool_bar_manager in self.tool_bar_managers:
             tool_bar_manager.destroy()
 
-        super(MApplicationWindow, self).destroy()
+        super().destroy()
 
     # ------------------------------------------------------------------------
     # Protected 'IApplicationWindow' interface.
