@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -15,4 +15,4 @@
 
 from pyface.toolkit import toolkit_object
 
-TreeViewer = toolkit_object("preference.preference_dialog:PreferenceDialog")
+PreferenceDialog = toolkit_object("preference.preference_dialog:PreferenceDialog")
