@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -28,12 +28,12 @@ class TestPyfaceResourceFactory(unittest.TestCase):
         self.resource_factory = PyfaceResourceFactory()
 
     def test_image_from_file(self):
-        image = self.resource_factory.image_from_file(IMAGE_PATH)
+        self.resource_factory.image_from_file(IMAGE_PATH)
 
     def test_image_from_data(self):
         with open(IMAGE_PATH, "rb") as fp:
             data = fp.read()
-        image = self.resource_factory.image_from_data(data)
+        self.resource_factory.image_from_data(data)
 
     def test_locate_image(self):
         class ASequence(Sequence):
