@@ -1,5 +1,5 @@
 # (C) Copyright 2007 Riverbank Computing Limited
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -15,7 +15,7 @@
 from inspect import getfullargspec
 
 
-from pyface.qt import QtGui, QtCore
+from pyface.qt import QtGui
 
 
 from traits.api import Any, Bool, HasTraits
@@ -26,7 +26,7 @@ from pyface.action.action_event import ActionEvent
 
 class PyfaceWidgetAction(QtGui.QWidgetAction):
     def __init__(self, parent, action):
-        super(PyfaceWidgetAction, self).__init__(parent)
+        super().__init__(parent)
         self.action = action
 
     def createWidget(self, parent):
@@ -98,9 +98,9 @@ class _MenuItem(HasTraits):
 
         if getattr(action, "menu_role", False):
             if action.menu_role == "About":
-                self.control.setMenuRole(QtGui.QAction.AboutRole)
+                self.control.setMenuRole(QtGui.QAction.MenuRole.AboutRole)
             elif action.menu_role == "Preferences":
-                self.control.setMenuRole(QtGui.QAction.PreferencesRole)
+                self.control.setMenuRole(QtGui.QAction.MenuRole.PreferencesRole)
 
         if action.style == "toggle":
             self.control.setCheckable(True)
@@ -374,6 +374,15 @@ class _Tool(HasTraits):
         """ Delete the reference to the control to avoid attempting to talk to
         it again.
         """
+        if self.control is not None:
+            # Remove the cycle since we're no longer needed.
+            try:
+                has_instance = hasattr(self.control, "_tool_instance")
+            # fixes mayavi #1180: PyQt5 "wrapped C/C++ object ... has been deleted"
+            except RuntimeError:
+                has_instance = False
+            if has_instance:
+                del self.control._tool_instance
         self.control = None
 
     def _qt4_on_triggered(self):
@@ -512,7 +521,6 @@ class _PaletteTool(HasTraits):
         # And they never contain shortcuts.
         label = label.replace("&", "")
 
-        image = action.image.create_image()
         path = action.image.absolute_path
         bmp = image_cache.get_bitmap(path)
 
@@ -574,8 +582,6 @@ class _PaletteTool(HasTraits):
         action = self.item.action
         action_event = ActionEvent()
 
-        is_checkable = action.style == "radio" or action.style == "check"
-
         # Perform the action!
         action.checked = self.tool_palette.get_tool_state(self.tool_id) == 1
         action.perform(action_event)
