@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -57,7 +57,7 @@ class StatusBarManager(HasTraits):
 
         return self.status_bar
 
-    def destroy_status_bar(self):
+    def destroy(self):
         """ Destroys the status bar. """
         if self.status_bar is not None:
             self.status_bar.deleteLater()
