@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -86,7 +86,10 @@ class FileDialog(MFileDialog, Dialog):
 
     def close(self):
         # Get the path of the chosen directory.
-        files = self.control.selectedFiles()
+        if self.control is not None:
+            files = self.control.selectedFiles()
+        else:
+            files = []
 
         if files:
             self.path = str(files[0])
@@ -99,12 +102,13 @@ class FileDialog(MFileDialog, Dialog):
         self.directory, self.filename = os.path.split(self.path)
 
         # Get the index of the selected filter.
-        self.wildcard_index = self.control.nameFilters().index(
-            self.control.selectedNameFilter()
-        )
+        if self.control is not None:
+            self.wildcard_index = self.control.nameFilters().index(
+                self.control.selectedNameFilter()
+            )
 
         # Let the window close as normal.
-        super(FileDialog, self).close()
+        super().close()
 
     # ------------------------------------------------------------------------
     # Protected 'IWidget' interface.
@@ -138,7 +142,7 @@ class FileDialog(MFileDialog, Dialog):
             default_directory = QtCore.QDir.currentPath()
 
         dlg = QtGui.QFileDialog(parent, self.title, default_directory)
-        dlg.setViewMode(QtGui.QFileDialog.Detail)
+        dlg.setViewMode(QtGui.QFileDialog.ViewMode.Detail)
         dlg.selectFile(default_filename)
         dlg.setNameFilters(filters)
 
@@ -146,14 +150,14 @@ class FileDialog(MFileDialog, Dialog):
             dlg.selectNameFilter(filters[self.wildcard_index])
 
         if self.action == "open":
-            dlg.setAcceptMode(QtGui.QFileDialog.AcceptOpen)
-            dlg.setFileMode(QtGui.QFileDialog.ExistingFile)
+            dlg.setAcceptMode(QtGui.QFileDialog.AcceptMode.AcceptOpen)
+            dlg.setFileMode(QtGui.QFileDialog.FileMode.ExistingFile)
         elif self.action == "open files":
-            dlg.setAcceptMode(QtGui.QFileDialog.AcceptOpen)
-            dlg.setFileMode(QtGui.QFileDialog.ExistingFiles)
+            dlg.setAcceptMode(QtGui.QFileDialog.AcceptMode.AcceptOpen)
+            dlg.setFileMode(QtGui.QFileDialog.FileMode.ExistingFiles)
         else:
-            dlg.setAcceptMode(QtGui.QFileDialog.AcceptSave)
-            dlg.setFileMode(QtGui.QFileDialog.AnyFile)
+            dlg.setAcceptMode(QtGui.QFileDialog.AcceptMode.AcceptSave)
+            dlg.setFileMode(QtGui.QFileDialog.FileMode.AnyFile)
 
         return dlg
 
