@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -11,7 +11,7 @@
 import sys
 
 
-from pyface.qt import QtCore, QtGui
+from pyface.qt import QtCore, QtGui, is_pyside, is_qt6
 
 
 from traits.api import (
@@ -55,7 +55,7 @@ class AdvancedEditorAreaPane(TaskPane, MEditorAreaPane):
         """ Create and set the toolkit-specific control that represents the
             pane.
         """
-        self.control = control = EditorAreaWidget(self, parent)
+        self.control = EditorAreaWidget(self, parent)
         self._filter = EditorAreaDropFilter(self)
         self.control.installEventFilter(self._filter)
 
@@ -80,10 +80,17 @@ class AdvancedEditorAreaPane(TaskPane, MEditorAreaPane):
         # Add shortcuts for switching to a specific tab.
         mod = "Ctrl+" if sys.platform == "darwin" else "Alt+"
         mapper = QtCore.QSignalMapper(self.control)
-        mapper.mapped.connect(self._activate_tab)
-        self._connections_to_remove.append(
-            (mapper.mapped, self._activate_tab)
-        )
+        if is_pyside and is_qt6:
+            mapper.mappedInt.connect(self._activate_tab)
+            self._connections_to_remove.append(
+                (mapper.mappedInt, self._activate_tab)
+            )
+        else:
+            mapper.mapped.connect(self._activate_tab)
+            self._connections_to_remove.append(
+                (mapper.mapped, self._activate_tab)
+            )
+
         for i in range(1, 10):
             sequence = QtGui.QKeySequence(mod + str(i))
             shortcut = QtGui.QShortcut(sequence, self.control)
@@ -110,7 +117,7 @@ class AdvancedEditorAreaPane(TaskPane, MEditorAreaPane):
             signal, handler = self._connections_to_remove.pop()
             signal.disconnect(handler)
 
-        super(AdvancedEditorAreaPane, self).destroy()
+        super().destroy()
 
     # ------------------------------------------------------------------------
     # 'IEditorAreaPane' interface.
@@ -151,7 +158,7 @@ class AdvancedEditorAreaPane(TaskPane, MEditorAreaPane):
         """ Returns a LayoutItem that reflects the current state of the editors.
         """
         return self._main_window_layout.get_layout_for_area(
-            QtCore.Qt.LeftDockWidgetArea
+            QtCore.Qt.DockWidgetArea.LeftDockWidgetArea
         )
 
     def set_layout(self, layout):
@@ -159,7 +166,7 @@ class AdvancedEditorAreaPane(TaskPane, MEditorAreaPane):
         """
         if layout is not None:
             self._main_window_layout.set_layout_for_area(
-                layout, QtCore.Qt.LeftDockWidgetArea
+                layout, QtCore.Qt.DockWidgetArea.LeftDockWidgetArea
             )
 
     # ------------------------------------------------------------------------
@@ -267,7 +274,7 @@ class EditorAreaWidget(QtGui.QMainWindow):
     # ------------------------------------------------------------------------
 
     def __init__(self, editor_area, parent=None):
-        super(EditorAreaWidget, self).__init__(parent)
+        super().__init__(parent)
         self.editor_area = editor_area
         self.reset_drag()
 
@@ -280,7 +287,7 @@ class EditorAreaWidget(QtGui.QMainWindow):
                 break
 
         # Monitor focus changes so we can set the active editor.
-        QtGui.QApplication.instance().focusChanged.connect(self._focus_changed)
+        QtGui.QApplication.instance().focusChanged.connect(self._update_active_editor)
 
         # Configure the QMainWindow.
         # FIXME: Currently animation is not supported.
@@ -288,21 +295,21 @@ class EditorAreaWidget(QtGui.QMainWindow):
         self.setAnimated(False)
         self.setDockNestingEnabled(True)
         self.setDocumentMode(True)
-        self.setFocusPolicy(QtCore.Qt.StrongFocus)
+        self.setFocusPolicy(QtCore.Qt.FocusPolicy.StrongFocus)
         self.setTabPosition(
-            QtCore.Qt.AllDockWidgetAreas, QtGui.QTabWidget.North
+            QtCore.Qt.DockWidgetArea.AllDockWidgetAreas, QtGui.QTabWidget.TabPosition.North
         )
 
     def _remove_event_listeners(self):
         """ Disconnects focusChanged signal of the application """
         app = QtGui.QApplication.instance()
-        app.focusChanged.disconnect(self._focus_changed)
+        app.focusChanged.disconnect(self._update_active_editor)
 
     def add_editor_widget(self, editor_widget):
         """ Adds a dock widget to the editor area.
         """
         editor_widget.installEventFilter(self)
-        self.addDockWidget(QtCore.Qt.LeftDockWidgetArea, editor_widget)
+        self.addDockWidget(QtCore.Qt.DockWidgetArea.LeftDockWidgetArea, editor_widget)
 
         # Try to place the editor in a sensible spot.
         top_left = None
@@ -451,19 +458,19 @@ class EditorAreaWidget(QtGui.QMainWindow):
     def childEvent(self, event):
         """ Reimplemented to gain access to the tab bars as they are created.
         """
-        super(EditorAreaWidget, self).childEvent(event)
+        super().childEvent(event)
         if event.polished():
             child = event.child()
             if isinstance(child, QtGui.QTabBar):
                 # Use UniqueConnections since Qt recycles the tab bars.
                 child.installEventFilter(self)
                 child.currentChanged.connect(
-                    self._tab_index_changed, QtCore.Qt.UniqueConnection
+                    self._update_editor_in_focus, QtCore.Qt.ConnectionType.UniqueConnection
                 )
                 child.setTabsClosable(True)
                 child.setUsesScrollButtons(True)
                 child.tabCloseRequested.connect(
-                    self._tab_close_requested, QtCore.Qt.UniqueConnection
+                    self._tab_close_requested, QtCore.Qt.ConnectionType.UniqueConnection
                 )
                 # FIXME: We would like to have the tabs movable, but this
                 # confuses the QMainWindowLayout. For now, we disable this.
@@ -486,12 +493,12 @@ class EditorAreaWidget(QtGui.QMainWindow):
     def _filter_dock_widget(self, widget, event):
         """ Support hover widget state tracking.
         """
-        if self._drag_widget and event.type() == QtCore.QEvent.Resize:
+        if self._drag_widget and event.type() == QtCore.QEvent.Type.Resize:
             if widget.geometry() == self._rubber_band.geometry():
                 self.set_hover_widget(widget)
 
         elif (
-            self._drag_widget == widget and event.type() == QtCore.QEvent.Move
+            self._drag_widget == widget and event.type() == QtCore.QEvent.Type.Move
         ):
             if len(self._tear_widgets) == 1 and not self._tear_handled:
                 widget = self._tear_widgets[0]
@@ -500,7 +507,7 @@ class EditorAreaWidget(QtGui.QMainWindow):
 
         elif (
             self._drag_widget == widget
-            and event.type() == QtCore.QEvent.MouseButtonRelease
+            and event.type() == QtCore.QEvent.Type.MouseButtonRelease
         ):
             self.reset_drag()
 
@@ -510,8 +517,8 @@ class EditorAreaWidget(QtGui.QMainWindow):
         """ Support hover widget state tracking.
         """
         if self._drag_widget and event.type() in (
-            QtCore.QEvent.Resize,
-            QtCore.QEvent.Move,
+            QtCore.QEvent.Type.Resize,
+            QtCore.QEvent.Type.Move,
         ):
             self.set_hover_widget(None)
 
@@ -520,7 +527,7 @@ class EditorAreaWidget(QtGui.QMainWindow):
     def _filter_tab_bar(self, tab_bar, event):
         """ Support 'tearing off' a tab.
         """
-        if event.type() == QtCore.QEvent.MouseMove:
+        if event.type() == QtCore.QEvent.Type.MouseMove:
             if tab_bar.rect().contains(event.pos()):
                 self.reset_drag()
             else:
@@ -531,18 +538,18 @@ class EditorAreaWidget(QtGui.QMainWindow):
 
                     pos = QtCore.QPoint(0, 0)
                     press_event = QtGui.QMouseEvent(
-                        QtCore.QEvent.MouseButtonPress,
+                        QtCore.QEvent.Type.MouseButtonPress,
                         pos,
                         widget.mapToGlobal(pos),
-                        QtCore.Qt.LeftButton,
-                        QtCore.Qt.LeftButton,
+                        QtCore.Qt.MouseButton.LeftButton,
+                        QtCore.Qt.MouseButton.LeftButton,
                         event.modifiers(),
                     )
                     QtCore.QCoreApplication.sendEvent(widget, press_event)
                     return True
 
                 event = QtGui.QMouseEvent(
-                    QtCore.QEvent.MouseMove,
+                    QtCore.QEvent.Type.MouseMove,
                     event.pos(),
                     event.globalPos(),
                     event.button(),
@@ -552,7 +559,7 @@ class EditorAreaWidget(QtGui.QMainWindow):
                 QtCore.QCoreApplication.sendEvent(self._drag_widget, event)
                 return True
 
-        elif event.type() == QtCore.QEvent.ToolTip:
+        elif event.type() == QtCore.QEvent.Type.ToolTip:
             # QDockAreaLayout forces the tooltips to be QDockWidget.windowTitle,
             # so we provide the tooltips manually.
             widgets = self.get_dock_widgets_for_bar(tab_bar)
@@ -575,20 +582,20 @@ class EditorAreaWidget(QtGui.QMainWindow):
     # Signal handlers.
     # ------------------------------------------------------------------------
 
-    def _focus_changed(self, old, new):
+    def _update_active_editor(self, old, new):
         """ Handle an application-level focus change.
         """
         if new is not None:
             for editor in self.editor_area.editors:
                 control = editor.control
                 if control is not None and control.isAncestorOf(new):
-                    self.editor_area.active_editor = focused = editor
+                    self.editor_area.active_editor = editor
                     break
             else:
                 if not self.editor_area.editors:
                     self.editor_area.active_editor = None
 
-    def _tab_index_changed(self, index):
+    def _update_editor_in_focus(self, index):
         """ Handle a tab selection.
         """
         widgets = self.get_dock_widgets_for_bar(self.sender())
@@ -608,13 +615,13 @@ class EditorWidget(QtGui.QDockWidget):
     """
 
     def __init__(self, editor, parent=None):
-        super(EditorWidget, self).__init__(parent)
+        super().__init__(parent)
         self.editor = editor
         self.editor.create(self)
-        self.setAllowedAreas(QtCore.Qt.LeftDockWidgetArea)
+        self.setAllowedAreas(QtCore.Qt.DockWidgetArea.LeftDockWidgetArea)
         self.setFeatures(
-            QtGui.QDockWidget.DockWidgetClosable
-            | QtGui.QDockWidget.DockWidgetMovable
+            QtGui.QDockWidget.DockWidgetFeature.DockWidgetClosable
+            | QtGui.QDockWidget.DockWidgetFeature.DockWidgetMovable
         )
         self.setWidget(editor.control)
         self.update_title()
@@ -672,7 +679,7 @@ class EditorTitleBarWidget(QtGui.QTabBar):
     """
 
     def __init__(self, editor_widget):
-        super(EditorTitleBarWidget, self).__init__(editor_widget)
+        super().__init__(editor_widget)
         self.addTab(editor_widget.windowTitle())
         self.setTabToolTip(0, editor_widget.editor.tooltip)
         self.setDocumentMode(True)
