@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -13,7 +13,7 @@ import os
 import tempfile
 import unittest
 
-from traits.api import HasTraits, Instance
+from traits.api import Instance
 
 from pyface.qt import QtGui, QtCore
 from pyface.tasks.split_editor_area_pane import (
@@ -93,7 +93,7 @@ class TestEditorAreaWidget(unittest.TestCase):
         btn1 = tabwidget.widget(1)
 
         # perform
-        root.split(orientation=QtCore.Qt.Horizontal)
+        root.split(orientation=QtCore.Qt.Orientation.Horizontal)
 
         # test
         # do we get correct leftchild and rightchild?
@@ -172,11 +172,8 @@ class TestEditorAreaWidget(unittest.TestCase):
         the tabs of the  collapsing tabwidgets.
         """
         # setup root
-        root, left, right = self._setUp_collapse()
-        btn0 = left.tabwidget().widget(0)
-        btn1 = left.tabwidget().widget(1)
+        root, _, right = self._setUp_collapse()
         btn2 = right.tabwidget().widget(0)
-        btn3 = right.tabwidget().widget(1)
 
         # perform collapse on rightchild
         root.rightchild.collapse()
@@ -285,7 +282,7 @@ class TestEditorAreaWidget(unittest.TestCase):
         self.assertFalse(right.is_leaf())
 
         # right pane is vertical splitter?
-        self.assertEqual(right.orientation(), QtCore.Qt.Vertical)
+        self.assertEqual(right.orientation(), QtCore.Qt.Orientation.Vertical)
 
         # top pane of this vertical split is empty?
         right_top = right.leftchild
@@ -336,6 +333,11 @@ class TestEditorAreaWidget(unittest.TestCase):
         self.assertEqual(right_bottom.items[0].id, 1)
         self.assertEqual(right_bottom.items[1].id, 2)
 
+        # Close all of the opened temporary files
+        file0.close()
+        file1.close()
+        file2.close()
+
     def test_context_menu_merge_text_left_right_split(self):
         # Regression test for enthought/pyface#422
         window = TaskWindow()
@@ -349,7 +351,7 @@ class TestEditorAreaWidget(unittest.TestCase):
 
         editor_area_widget = editor_area.control
         with event_loop():
-            editor_area_widget.split(orientation=QtCore.Qt.Horizontal)
+            editor_area_widget.split(orientation=QtCore.Qt.Orientation.Horizontal)
 
         # Get the tabs.
         left_tab, right_tab = editor_area_widget.tabwidgets()
@@ -386,7 +388,7 @@ class TestEditorAreaWidget(unittest.TestCase):
 
         editor_area_widget = editor_area.control
         with event_loop():
-            editor_area_widget.split(orientation=QtCore.Qt.Vertical)
+            editor_area_widget.split(orientation=QtCore.Qt.Orientation.Vertical)
 
         # Get the tabs.
         top_tab, bottom_tab = editor_area_widget.tabwidgets()
@@ -429,7 +431,7 @@ class TestEditorAreaWidget(unittest.TestCase):
         # reliably outside.
         pos = QtCore.QPoint(-1, -1)
         context_menu_event = QtGui.QContextMenuEvent(
-            QtGui.QContextMenuEvent.Mouse, pos
+            QtGui.QContextMenuEvent.Reason.Mouse, pos
         )
 
         global_pos = editor_area_widget.mapToGlobal(pos)
@@ -500,7 +502,7 @@ class TestEditorAreaWidget(unittest.TestCase):
         with event_loop():
             editor_area.add_editor(left_editor)
         with event_loop():
-            editor_area.control.split(orientation=QtCore.Qt.Horizontal)
+            editor_area.control.split(orientation=QtCore.Qt.Orientation.Horizontal)
         with event_loop():
             editor_area.add_editor(right_editor)
 
@@ -516,6 +518,80 @@ class TestEditorAreaWidget(unittest.TestCase):
         with event_loop():
             window.close()
 
+    def test_editor_label_change_inactive(self):
+        # regression test for pyface#523
+        window = TaskWindow(size=(800, 600))
 
-if __name__ == "__main__":
-    unittest.main()
+        task = SplitEditorAreaPaneTestTask()
+        editor_area = task.editor_area
+        window.add_task(task)
+
+        # Show the window.
+        with event_loop():
+            window.open()
+
+        with event_loop():
+            app = get_app_qt4()
+            app.setActiveWindow(window.control)
+
+        # Add and activate an editor which contains tabs.
+        left_editor = ViewWithTabsEditor()
+        right_editor = ViewWithTabsEditor()
+
+        with event_loop():
+            editor_area.add_editor(left_editor)
+        with event_loop():
+            editor_area.control.split(orientation=QtCore.Qt.Orientation.Horizontal)
+        with event_loop():
+            editor_area.add_editor(right_editor)
+
+        editor_area.activate_editor(right_editor)
+
+        # change the name of the inactive editor
+        left_editor.name = "New Name"
+
+        # the text of the editor's tab should have changed
+        left_tabwidget = editor_area.tabwidgets()[0]
+        index = left_tabwidget.indexOf(left_editor.control)
+        tab_text = left_tabwidget.tabText(index)
+
+        self.assertEqual(tab_text, "New Name")
+
+    def test_editor_tooltip_change_inactive(self):
+        # regression test related to pyface#523
+        window = TaskWindow(size=(800, 600))
+
+        task = SplitEditorAreaPaneTestTask()
+        editor_area = task.editor_area
+        window.add_task(task)
+
+        # Show the window.
+        with event_loop():
+            window.open()
+
+        with event_loop():
+            app = get_app_qt4()
+            app.setActiveWindow(window.control)
+
+        # Add and activate an editor which contains tabs.
+        left_editor = ViewWithTabsEditor()
+        right_editor = ViewWithTabsEditor()
+
+        with event_loop():
+            editor_area.add_editor(left_editor)
+        with event_loop():
+            editor_area.control.split(orientation=QtCore.Qt.Orientation.Horizontal)
+        with event_loop():
+            editor_area.add_editor(right_editor)
+
+        editor_area.activate_editor(right_editor)
+
+        # change the name of the inactive editor
+        left_editor.tooltip = "New Tooltip"
+
+        # the text of the editor's tab should have changed
+        left_tabwidget = editor_area.tabwidgets()[0]
+        index = left_tabwidget.indexOf(left_editor.control)
+        tab_tooltip = left_tabwidget.tabToolTip(index)
+
+        self.assertEqual(tab_tooltip, "New Tooltip")
