@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -13,4 +13,4 @@ DoLaterTimer class
 Provided for backward compatibility.
 """
 
-from pyface.timer.do_later import DoLaterTimer
+from pyface.timer.do_later import DoLaterTimer  # noqa: F401
