@@ -1,5 +1,5 @@
 # (C) Copyright 2007 Riverbank Computing Limited
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -9,6 +9,7 @@
 #
 # Thanks for using Enthought open source!
 
+import weakref
 
 from pyface.qt import QtCore, QtGui
 
@@ -111,7 +112,6 @@ class Window(MWindow, Widget):
     # -------------------------------------------------------------------------
 
     def destroy(self):
-        self._remove_event_listeners()
 
         if self.control is not None:
             # Avoid problems with recursive calls.
@@ -119,14 +119,15 @@ class Window(MWindow, Widget):
             # so we need a reference to control
             control = self.control
 
-            # Widget.destroy() hides the widget, sets self.control to None
-            # and deletes it later, so we call it before control.close()
+            # Widget.destroy() sets self.control to None and deletes it later,
+            # so we call it before control.close()
             # This is not strictly necessary (closing the window in fact
             # hides it), but the close may trigger an application shutdown,
             # which can take a long time and may also attempt to recursively
             # destroy the window again.
-            super(Window, self).destroy()
+            super().destroy()
             control.close()
+            control.hide()
 
     # -------------------------------------------------------------------------
     # Private interface.
@@ -171,11 +172,11 @@ class Window(MWindow, Widget):
 
         if state == "maximized":
             control.setWindowState(
-                control.windowState() | QtCore.Qt.WindowMaximized
+                control.windowState() | QtCore.Qt.WindowState.WindowMaximized
             )
         elif state == "normal":
             control.setWindowState(
-                control.windowState() & ~QtCore.Qt.WindowMaximized
+                control.windowState() & ~QtCore.Qt.WindowState.WindowMaximized
             )
 
     def _title_changed(self, title):
@@ -196,20 +197,22 @@ class WindowEventFilter(QtCore.QObject):
     def __init__(self, window):
         """ Initialise the event filter. """
         QtCore.QObject.__init__(self)
-        self._window = window
+        # use a weakref to fix finalization issues with circular references
+        # we don't want to be the last thing holding a reference to the window
+        self._window = weakref.ref(window)
 
     def eventFilter(self, obj, e):
         """ Adds any event listeners required by the window. """
 
-        window = self._window
+        window = self._window()
 
         # Sanity check.
-        if obj is not window.control:
+        if window is None or obj is not window.control:
             return False
 
         typ = e.type()
 
-        if typ == QtCore.QEvent.Close:
+        if typ == QtCore.QEvent.Type.Close:
             # Do not destroy the window during its event handler.
             GUI.invoke_later(window.close)
 
@@ -218,29 +221,29 @@ class WindowEventFilter(QtCore.QObject):
 
             return True
 
-        if typ == QtCore.QEvent.WindowActivate:
+        if typ == QtCore.QEvent.Type.WindowActivate:
             window.activated = window
 
-        elif typ == QtCore.QEvent.WindowDeactivate:
+        elif typ == QtCore.QEvent.Type.WindowDeactivate:
             window.deactivated = window
 
-        elif typ in {QtCore.QEvent.Show, QtCore.QEvent.Hide}:
+        elif typ in {QtCore.QEvent.Type.Show, QtCore.QEvent.Type.Hide}:
             window.visible = window.control.isVisible()
 
-        elif typ == QtCore.QEvent.Resize:
+        elif typ == QtCore.QEvent.Type.Resize:
             # Get the new size and set the shadow trait without performing
             # notification.
             size = e.size()
             window._size = (size.width(), size.height())
 
-        elif typ == QtCore.QEvent.Move:
+        elif typ == QtCore.QEvent.Type.Move:
             # Get the real position and set the trait without performing
             # notification. Don't use event.pos(), as this excludes the window
             # frame geometry.
             pos = window.control.pos()
             window._position = (pos.x(), pos.y())
 
-        elif typ == QtCore.QEvent.KeyPress:
+        elif typ == QtCore.QEvent.Type.KeyPress:
             # Pyface doesn't seem to be Str aware.  Only keep the key code
             # if it corresponds to a single Latin1 character.
             kstr = e.text()
@@ -252,23 +255,23 @@ class WindowEventFilter(QtCore.QObject):
             mods = e.modifiers()
             window.key_pressed = KeyPressedEvent(
                 alt_down=(
-                    (mods & QtCore.Qt.AltModifier) == QtCore.Qt.AltModifier
+                    (mods & QtCore.Qt.KeyboardModifier.AltModifier) == QtCore.Qt.KeyboardModifier.AltModifier
                 ),
                 control_down=(
-                    (mods & QtCore.Qt.ControlModifier)
-                    == QtCore.Qt.ControlModifier
+                    (mods & QtCore.Qt.KeyboardModifier.ControlModifier)
+                    == QtCore.Qt.KeyboardModifier.ControlModifier
                 ),
                 shift_down=(
-                    (mods & QtCore.Qt.ShiftModifier) == QtCore.Qt.ShiftModifier
+                    (mods & QtCore.Qt.KeyboardModifier.ShiftModifier) == QtCore.Qt.KeyboardModifier.ShiftModifier
                 ),
                 key_code=kcode,
                 event=e,
             )
 
-        elif typ == QtCore.QEvent.WindowStateChange:
+        elif typ == QtCore.QEvent.Type.WindowStateChange:
             # set the size_state of the window.
             state = obj.windowState()
-            if state & QtCore.Qt.WindowMaximized:
+            if state & QtCore.Qt.WindowState.WindowMaximized:
                 window.size_state = "maximized"
             else:
                 window.size_state = "normal"
