@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -17,10 +17,10 @@
 """ A page in a wizard. """
 
 
-from pyface.qt import QtCore, QtGui
+from pyface.qt import QtGui
 
 
-from traits.api import Bool, HasTraits, provides, Str, Tuple, Str
+from traits.api import Bool, HasTraits, provides, Str, Tuple
 from pyface.wizard.i_wizard_page import IWizardPage, MWizardPage
 
 
@@ -99,7 +99,7 @@ class WizardPage(MWizardPage, HasTraits):
         control = QtGui.QWidget(parent)
 
         palette = control.palette()
-        palette.setColor(QtGui.QPalette.Window, QtGui.QColor("yellow"))
+        palette.setColor(QtGui.QPalette.ColorRole.Window, QtGui.QColor("yellow"))
         control.setPalette(palette)
         control.setAutoFillBackground(True)
 
