@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -50,7 +50,7 @@ class StatusBarManager(HasTraits):
 
         return self.status_bar
 
-    def remove_status_bar(self, parent):
+    def destroy(self, parent):
         """ Removes a status bar. """
 
         if self.status_bar is not None:
