@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -21,7 +21,7 @@ class CheckboxRenderer(GridCellRenderer):
     def __init__(self, **traits):
 
         # base-class constructor
-        super(CheckboxRenderer, self).__init__(**traits)
+        super().__init__(**traits)
 
         # initialize the renderer, if it hasn't already been initialized
         if self.renderer is None:
