@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -47,6 +47,9 @@ class MessageDialog(MMessageDialog, Dialog):
 
     severity = Enum("information", "warning", "error")
 
+    # unused trait, this functionality is only supported on Qt
+    text_format = Enum("auto", "plain", "rich")
+
     # ------------------------------------------------------------------------
     # Protected 'IDialog' interface.
     # ------------------------------------------------------------------------
