@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -10,7 +10,6 @@
 
 import tempfile
 import shutil
-import os
 import unittest
 from unittest import mock
 
@@ -18,7 +17,6 @@ from traits.testing.api import UnittestTools
 
 from pyface.workbench.perspective import Perspective
 from pyface.workbench.api import Workbench
-from pyface.workbench.user_perspective_manager import UserPerspectiveManager
 from pyface.workbench.workbench_window import (
     WorkbenchWindow,
     WorkbenchWindowLayout,
