@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -8,16 +8,10 @@
 #
 # Thanks for using Enthought open source!
 
-from numpy import arange
-
 import wx
 from wx.grid import Grid
-from wx.grid import PyGridCellRenderer
-from wx.grid import GridCellTextEditor, GridCellStringRenderer
 from wx.grid import GridCellFloatRenderer, GridCellFloatEditor
 
-from wx.lib.mixins.grid import GridAutoEditMixin
-
 
 class AbstractGridView(Grid):
     """ Enthought's default spreadsheet view.
@@ -174,7 +168,7 @@ class AbstractGridView(Grid):
         of a spreadsheet. See also self.OnSelectCell().
         """
 
-        if self.edit == True:
+        if self.edit:
             if self.CanEnableCellControl():
                 self.EnableCellEditControl()
             self.edit = False
@@ -201,6 +195,3 @@ class AbstractGridView(Grid):
 
     def OnEditorCreated(self, evt):
         evt.Skip()
-
-
-# -------------------------------------------------------------------------------
